@@ -8,19 +8,19 @@
 Commodore 128 [computer] (Commodore)
 
 @item C2IS
-Command and Control Information Systems mil., USA
+Command and Control Information Systems (mil., USA)
 
 @item C3I
-Command, Control, Communications and Intelligence mil., USA
+Command, Control, Communications and Intelligence (mil., USA)
 
 @item C3IIS
-Command, Control, Communications and Intelligence Information Systems mil., USA, "C3I/IS"
+Command, Control, Communications and Intelligence Information Systems (mil., USA), "C3I/IS"
 
 @item C4
-Command, Control, Communications and Computers mil., USA
+Command, Control, Communications and Computers (mil., USA)
 
 @item C4I
-Command, Control, Communications, Computers and Intelligence mil., USA
+Command, Control, Communications, Computers and Intelligence (mil., USA)
 
 @item C64
 Commodore 64 [computer] (Commodore)
@@ -29,13 +29,13 @@ Commodore 64 [computer] (Commodore)
 Cell Arrival (ATM)
 
 @item CA
-Certification Authority cryptography
+Certification Authority (cryptography)
 
 @item CA
 Computer Animation
 
 @item CA
-Computer Associates manufacturer
+Computer Associates (manufacturer)
 
 @item CAAD
 Computer Aided Architectural Design
@@ -53,7 +53,7 @@ Connection Admission Control (UNI, ATM)
 Computer-Assisted Circuit Engineering and Allocating System
 
 @item CACTIS
-Community Automated Counter-Terrorism Intelligence System mil., USA
+Community Automated Counter-Terrorism Intelligence System (mil., USA)
 
 @item CAD
 Computer Aided  Dispatch / Drafting
@@ -86,16 +86,16 @@ Computer Aided Inspection (CIM)
 Computer Aided Instruction
 
 @item CAIP
-Computer Analysis of Images and Patterns conference
+Computer Analysis of Images and Patterns (conference)
 
 @item CAIS
 Common APSE Interface Specification
 
 @item CAIT
-Center for the Application of Information Technology org., USA
+Center for the Application of Information Technology (org., USA)
 
 @item CAIT
-Central Academy of Information Technology org., MITI
+Central Academy of Information Technology (org., MITI)
 
 @item CAL
 Computer Aided Logistics
@@ -146,13 +146,13 @@ Computer Aided Planning (CIM)
 Computer Aided Publishing
 
 @item CAPE
-Computer Applications in Production and Engineering conference, IFIP
+Computer Applications in Production and Engineering (conference, IFIP)
 
 @item CAPI
 Communication Application Program Interface (ISDN, API)
 
 @item CAPI
-Cryptography Application Programming Interface cryptography, API
+Cryptography Application Programming Interface (cryptography, API)
 
 @item CAPP
 Computer Aided Process Planning
@@ -176,7 +176,7 @@ Computer Assisted Radiology
 Computer Aided aRchiving and Change Accounting System
 
 @item CARDS
-Central Archive for Reusable Defense Software mil., USA
+Central Archive for Reusable Defense Software (mil., USA)
 
 @item CARE
 Computer Assistance Resource Exchange
@@ -209,7 +209,7 @@ Computer Aided Software Engineering
 Computer Aided Service Handling (Ashton-Tate), "C.A.S.H."
 
 @item CAST
-??? cryptography
+??? (cryptography)
 
 @item CAST
 Computer Aided Software Testing
@@ -221,7 +221,7 @@ Central Alaska Time [-1000] (TZ)
 Common Authentication Technology (IETF, RFC 1511)
 
 @item CAT
-Computer Aided Technology fair
+Computer Aided Technology (fair)
 
 @item CAT
 Computer Aided Telephony
@@ -233,13 +233,13 @@ Computer Aided Testing
 Computer Aided Telephone Interviewing
 
 @item CATIS
-Computer-Assisted Tactical Information System mil., USA
+Computer-Assisted Tactical Information System (mil., USA)
 
 @item CATNIP
 Common ArchiTecture for Next generation Internet Protocol (IPNG, RFC 1707)
 
 @item CAUCE
-Coalition Against Unsolicited Commercial Email org., Internet, Spam, UCE
+Coalition Against Unsolicited Commercial Email (org., Internet, spam, UCE)
 
 @item CAV
 Constant Angular Velocity (CD, HDD, MOD)
@@ -254,7 +254,7 @@ Computer Associates - Visual Objects (CA, DB), "CA-VO"
 Commercial Beginners All purpose Symbolic Instruction Code (BASIC)
 
 @item CBC
-Cipher Block Chaining [mode] DES, DESE, RC5, cryptography
+Cipher Block Chaining [mode] (DES, DESE, RC5, cryptography)
 
 @item CBCP
 CallBack Control Protocol
@@ -266,13 +266,13 @@ Computer Based Conversation System (BBS)
 Character Bitmap Distribution Format (Adobe)
 
 @item CBDS
-Connectionless Broadband Data Service Europe
+Connectionless Broadband Data Service (Europe)
 
 @item CBE
 Certified Banyan Engineer (Banyan, VINES)
 
 @item CBEMA
-Computer & Business Equipment Manufacturers Association org.
+Computer & Business Equipment Manufacturers Association (org.)
 
 @item CBF
 Code Behind Form (MS, Access, DB)
@@ -320,7 +320,7 @@ Cross Connector
 Call Control Agent Function (IN)
 
 @item CCC
-Chaos Computer Club org.
+Chaos Computer Club (org.)
 
 @item CCC
 Computer Control Center
@@ -329,13 +329,13 @@ Computer Control Center
 Cube Connected Cycles (MP)
 
 @item CCCA
-Campus Computer Communication Association org., USA
+Campus Computer Communication Association (org., USA)
 
 @item CCCH
 Common Control CHannel (GSM)
 
 @item CCCI
-Center for Cyber Communities Initiative org., Japan
+Center for Cyber Communities Initiative (org., Japan)
 
 @item CCD
 Charge Coupled Device
@@ -347,10 +347,10 @@ Charge Coupled Device
 Connection Control Entity
 
 @item CCETT
-Centre Commun d'Etudes de Telediffusion et Telecommunications Org., France
+Centre Commun d'Etudes de Telediffusion et Telecommunications (org., France)
 
 @item CCF
-??? org.
+??? (org.)
 
 @item CCF
 Central Computer Facility
@@ -365,16 +365,16 @@ Cold Cathode Fluorescent Lamp
 Cold Cathode Fluorescent Tube (LCD, Display)
 
 @item CCIRN
-Coordinating Committee of International Networks org.
+Coordinating Committee of International Networks (org.)
 
 @item CCIS
 Common Channel Interoffice Signaling (AT&T)
 
 @item CCITT
-Comite Consultatif International Telegraphique et Telephonique org., ITU, Vorlaeufer
+Comite Consultatif International Telegraphique et Telephonique (org., ITU, predecessor)
 
 @item CCL
-Cerberus Central Limited manufacturer
+Cerberus Central Limited (manufacturer)
 
 @item CCM
 Change Configuration Management
@@ -404,10 +404,10 @@ Commitment, Concurrency and Recovery (OSI)
 Current Cell Rate (ATM)
 
 @item CCRMA
-Center for Computer Research in Music and Acoustics org., Stanford, UK
+Center for Computer Research in Music and Acoustics (org., Stanford, UK)
 
 @item CCS
-Cambridge Cybernetic Society org.
+Cambridge Cybernetic Society (org.)
 
 @item CCS
 Common Channel Signaling (IN)
@@ -434,7 +434,7 @@ Cooperative Computing System Program (HP)
 China Coast Time [+0800] (TZ)
 
 @item CCTA
-Central Computer and Telecommunications Agency org., UK
+Central Computer and Telecommunications Agency (org., UK)
 
 @item CCU
 Cache Control Unit (Wyse)
@@ -467,16 +467,16 @@ Connectionless Data Bearer Service
 Computerized Digital Branch eXchange (PBX)
 
 @item CDC
-Control Data Corporation manufacturer
+Control Data Corporation (manufacturer)
 
 @item CDC
-Cult of the Dead Cow org., "cDc"
+Cult of the Dead Cow (org.), "cDc"
 
 @item CDD
 Component Design Document
 
 @item CDDA
-Compact Disk - Digital Audio CD, digital audio, "CD-DA"
+Compact Disk - Digital Audio (CD, digital audio), "CD-DA" 
 
 @item CDDI
 Copper Distributed Data Interface (FDDI, UTP)
@@ -485,7 +485,7 @@ Copper Distributed Data Interface (FDDI, UTP)
 Common Desktop Environment
 
 @item CDE
-Compact Disk - Erasable (CD), "CD-E"
+Compact Disk - Erasable (CD), "CD-E" 
 
 @item CDE
 Cooperative Development Environment (Oracle)
@@ -500,10 +500,10 @@ Compound Document Framework (IBM, OLE)
 Compact Disk File System (CD, OS/2, IBM)
 
 @item CDG
-Compact Disk + Graphics (CD), "CD+G"
+Compact Disk + Graphics (CD), "CD+G" 
 
 @item CDI
-Compact Disk - Interactive (CD), "CD-I"
+Compact Disk - Interactive (CD), "CD-I" 
 
 @item CDIF
 CASE Data Interchange Format (CASE)
@@ -518,10 +518,10 @@ Compressed Data Mode
 Code Division Multiple Access (DFUE)
 
 @item CDMIDI
-Compact Disk + Musical Instruments Digital Interface (CD, MIDI), "CD+MIDI"
+Compact Disk + Musical Instruments Digital Interface (CD, MIDI), "CD+MIDI" 
 
 @item CDMO
-Compact Disk - Magneto Optical (CD), "CD-MO"
+Compact Disk - Magneto Optical (CD), "CD-MO" 
 
 @item CDMS
 Communication Driver Maintenance System (ISDN, HST)
@@ -533,7 +533,7 @@ Cellular Digital Packet Data
 Cellular Digital Packet Data (Mobile Systems)
 
 @item CDR
-Compact Disk - Recordable (CD), "CD-R"
+Compact Disk - Recordable (CD), "CD-R" 
 
 @item CDRA
 Character Data Representation Architecture
@@ -545,10 +545,10 @@ Cached Dynamic Random Access Memory (RAM, DRAM, IC)
 Cross DOMAIN Resource Manager (VTAM, SSCP, IBM)
 
 @item CDROM
-Compact Disk - Read Only Memory (CD), "CD-ROM"
+Compact Disk - Read Only Memory (CD), "CD-ROM" 
 
 @item CDROMXA
-Compact Disk - ROM / eXtended Architecture (CD, MPC), "CD-ROM/XA"
+Compact Disk - ROM / eXtended Architecture (CD, MPC), "CD-ROM/XA" 
 
 @item CDRW
 Compact Disk - ReWritable (CD), "CD-RW"
@@ -560,7 +560,7 @@ Cell Directory Service (DCE)
 Current Directory Structure (BIOS. DOS)
 
 @item CDSA
-Common Data Securuty Architecture HP, cryptography
+Common Data Securuty Architecture (HP, cryptography)
 
 @item CDSS
 Creative Decision Stimulation Systems (AI, DSS)
@@ -581,10 +581,10 @@ Cell Delay Variation (UNI, ATM, QOS)
 Cell Delay Variation Tolerance (UNI, ATM, CDV)
 
 @item CDWO
-Compact Disk - Write Once (CD), "CD-WO"
+Compact Disk - Write Once (CD), "CD-WO" 
 
 @item CE
-Communaute / Comunique Europeenne Europe
+Communaute / Comunique Europeenne (Europe)
 
 @item CE
 Communications-Electronics, "C-E"
@@ -599,10 +599,10 @@ Connection Endpoint (UNI)
 Cisco Educational ARCHive (Cisco, WWW)
 
 @item CEBIT
-welt CEntrum Buero Information Telekommunikation fair, "CeBIT"
+welt CEntrum Buero Information Telekommunikation (fair), "CeBIT"
 
 @item CEECEB
-Central and Eastern European Countries EDIFACT Board org., EDIFACT, "CEEC/EB"
+Central and Eastern European Countries EDIFACT Board (org., EDIFACT), "CEEC/EB"
 
 @item CEG
 Continuous Edge Graphics (Grafik, IC)
@@ -617,28 +617,28 @@ Card Edge Low Profile [socket]
 Code Excited Linear Prediction
 
 @item CEN
-Comite Europeen de Normalisation Europa, Brussels
+Comite Europeen de Normalisation (Europe, Brussels)
 
 @item CENELEC
-Comite Europeen de Normalisation ELECtrotechnique Org., CEN, Europe
+Comite Europeen de Normalisation ELECtrotechnique (org., CEN, Europe)
 
 @item CEPAC
 CMOS-Ein-Platinen-Allzweck-Computer (IC, CMOS, C'T)
 
 @item CEPIS
-Council of European Professional Informatics Societies Org., Europe
+Council of European Professional Informatics Societies (org., Europe)
 
 @item CEPT
-Conference of European Postal and Telecommunications administrations Org., CCITT, conference, Europa
+Conference of European Postal and Telecommunications administrations (org., CCITT, conference, Europe)
 
 @item CER
 Cell Error Ratio (ATM)
 
 @item CERFNET
-California Educational and Research Federation NETwork network, "CERFNet"
+California Educational and Research Federation NETwork (network), "CERFNet"
 
 @item CERN
-Conseil Europeenne pour la Recherche Nucleaire Org., Europe, Genf
+Conseil Europeenne pour la Recherche Nucleaire (org., Europe, Geneva)
 
 @item CERT
 Computer Emergency Response Team (DARPA, CMU, Internet)
@@ -650,7 +650,7 @@ C-bit Errored Seconds (DS3/E3)
 Circuit Emulation Service
 
 @item CES
-Consumer Electronics Show fair, USA
+Consumer Electronics Show (fair, USA)
 
 @item CESAR
 Central Employment Search And Retrieval (WWW)
@@ -659,19 +659,19 @@ Central Employment Search And Retrieval (WWW)
 Central European Time [+0100] (TZ, MET)
 
 @item CET
-Centro de Estudes de Telecomunicoes org., Portugal
+Centro de Estudes de Telecomunicoes (org., Portugal)
 
 @item CF
-Carry Flag assembler
+Carry Flag (assembler)
 
 @item CFA
-Center for Architecture org., JIEO, DISA
+Center for Architecture (org., JIEO, DISA)
 
 @item CFA
 Code Fiels Address (Forth)
 
 @item CFB
-Cipher FeedBack [mode] cryptography, DES
+Cipher FeedBack [mode] (cryptography, DES)
 
 @item CFD
 Call For Discussion (Internet)
@@ -680,25 +680,25 @@ Call For Discussion (Internet)
 Computational Fluid Dynamics [applications]
 
 @item CFE
-Center for Engineering org., JIEO, DISA
+Center for Engineering (org., JIEO, DISA)
 
 @item CFF
 Compact Font Format (Adobe)
 
 @item CFI
-CAD Framework Initiative org., CAD
+CAD Framework Initiative (org., CAD)
 
 @item CFM
 ConFiguration Management (FDDI, SMT)
 
 @item CFMC
-Committee to Fight Microsoft Corporation org., MS
+Committee to Fight Microsoft Corporation (org., MS)
 
 @item CFP
 Call For Papers
 
 @item CFS
-Center for Standards org., JIEO, DISA
+Center for Standards (org., JIEO, DISA)
 
 @item CFV
 Call For Vote (Internet, Usenet), "CfV"
@@ -707,10 +707,10 @@ Call For Vote (Internet, Usenet), "CfV"
 Colour Graphics Adapter
 
 @item CGA
-Graphics Communications Association org.
+Graphics Communications Association (org.)
 
 @item CGARI
-Graphics Communications Association Research Institute org., CGA
+Graphics Communications Association Research Institute (org., CGA)
 
 @item CGDC
 Computer (???) Game Developers' Conference
@@ -725,7 +725,7 @@ Computer Generated Imagery
 Computer Graphics Interface
 
 @item CGI
-Computer Graphics International conference
+Computer Graphics International (conference)
 
 @item CGM
 Computer Graphics Metafile (ISO 8632)
@@ -752,7 +752,7 @@ CHange Code Page (DOS)
 Computer Hardware Description Language (HDL)
 
 @item CHEST
-Computers in Higher Education Software Team org., UK
+Computers in Higher Education Software Team (org., UK)
 
 @item CHILL
 CCITT HIgh Level programming Language (CCITT)
@@ -779,7 +779,7 @@ Configuration Item (CM)
 Congestion Indicator
 
 @item CIAC
-Computer Incident Advisory Capability org., LLNL, Internet
+Computer Incident Advisory Capability (org., LLNL, Internet)
 
 @item CIB
 Computer Integrated Business
@@ -791,7 +791,7 @@ Carrier Identification Code
 Coordination and Information Center (CSNET)
 
 @item CICA
-Center of Innovative Computer Applications org.
+Center of Innovative Computer Applications (org.)
 
 @item CICS
 Customer Information Control System (IBM)
@@ -805,6 +805,9 @@ Customer Information Control System / Virtual Storage (IBM), "CICS/VS"
 @item CID
 Configuration - Installation - Distribution (IBM)
 
+@item CIDF
+Common Intrusion Detection Framework (CIDF, IDS)
+
 @item CIDIR
 Classless Internet DOMAIN Routing [protocol] (???, CIDR)
 
@@ -812,16 +815,16 @@ Classless Internet DOMAIN Routing [protocol] (???, CIDR)
 Classless Internet DOMAIN Routing [protocol] (RFC 1519)
 
 @item CIE
-Commission Internationale de l'Eclairage org.
+Commission Internationale de l'Eclairage (org.)
 
 @item CIFS
 Common Internet File System
 
 @item CIL
-Computer Integration Laboratories org., Apple, IBM, Novell, Sun, ...
+Computer Integration Laboratories (org., Apple, IBM, Novell, Sun, ...)
 
 @item CILABS
-Component Integration LABoratorieS org.,, OpenDoc, Apple, IBM, Adobe, ..., CILabs
+Component Integration LABoratorieS (org.,, OpenDoc, Apple, IBM, Adobe, ...), CILabs
 
 @item CIM
 Computer Integrated Manufacturing
@@ -848,28 +851,31 @@ Committed Information Rate (ATM)
 Cross Interleaved Reed-solomon Code (CD)
 
 @item CIRCIT
-Centre for International Research on Communication and Information Technology Org., Australia
+Centre for International Research on Communication and Information Technology (org., Australia)
 
 @item CIS
 Card Information Structure / Space (PCMCIA)
 
 @item CIS
-Command Information System mil., USA
+Command Information System (mil., USA)
 
 @item CIS
-Compuserve Information Systems network
+Compuserve Information Systems (network)
 
 @item CISC
 Complex Instruction Set Computer (CPU)
 
 @item CISE
-Computer and Information Science Directorate org., NSF
+Computer and Information Science Directorate (org., NSF)
+
+@item CISKA
+[3D] Campus-InformationsSystem KArlsruhe (Uni Karlsruhe, Germany, VRML)
 
 @item CISPR
-Comite International Special des Perturbations Radioelectriques org.
+Comite International Special des Perturbations Radioelectriques (org.)
 
 @item CISS
-Center for Information Systems Security Org., JIEO, DISA, mil., USA
+Center for Information Systems Security (org., JIEO, DISA, mil., USA)
 
 @item CIT
 Computer Integrated Telephony
@@ -902,11 +908,14 @@ Certified Lotus Engineer (Lotus)
 Call Level Interface (SAQ, X/Open, Informix, ...)
 
 @item CLI
-CLear Interrupt assembler
+CLear Interrupt (assembler)
 
 @item CLI
 Command Line Interpreter / Interface (OS)
 
+@item CLIC
+Computer Liability Insurance Coverage
+
 @item CLID
 Calling Line IDentification
 
@@ -974,16 +983,16 @@ Connection Machine 5 (TMC)
 Common Messaging Calls [interface] (XAPIA)
 
 @item CMC
-Complement Carry Flag assembler
+Complement Carry Flag (assembler)
 
 @item CMC
-Computer Mediated Communications [studies centre] org., USA
+Computer Mediated Communications [studies centre] (org., USA)
 
 @item CME
 Component Management Entity
 
 @item CMGS
-Cyan Magenta Gelb Schwarz color system, DTP
+Cyan Magenta Gelb Schwarz (color system, DTP)
 
 @item CMI
 Coded Mark Inversion
@@ -992,7 +1001,7 @@ Coded Mark Inversion
 Connection Manager Interface (IBM, SNA)
 
 @item CMIA
-China Medical Informatics Association org., China
+China Medical Informatics Association (org., China)
 
 @item CMIP
 Common Management Information Protocol (OSI, ISO, DP 9506, X.700)
@@ -1037,13 +1046,13 @@ Conversational Monitor System (IBM, VME)
 Connection ManagemenT (FDDI)
 
 @item CMU
-Carnegie-Mellon-University org.
+Carnegie-Mellon-University (org.)
 
 @item CMY
-Cyan Magenta Yellow color system, DTP
+Cyan Magenta Yellow (color system, DTP)
 
 @item CMYK
-Cyan Magenta Yellow blacK color system, DTP
+Cyan Magenta Yellow blacK (color system, DTP)
 
 @item CN
 Communications Network
@@ -1067,7 +1076,7 @@ Communication Network Architecture (SEL)
 Communications Network Application
 
 @item CNBC
-Center for Neural Basis of Cognition org., CMU, AI
+Center for Neural Basis of Cognition (org., CMU, AI)
 
 @item CNC
 Communications Network Control
@@ -1085,10 +1094,10 @@ Caller Number Delivery (MODEM)
 Certified Netware Engineer (Novell, Netware)
 
 @item CNEPA
-Certified Netware Engineers Professional Association org., Netware
+Certified Netware Engineers Professional Association (org., Netware)
 
 @item CNET
-Centre Nationale d'Etudes des Telecommunications Org., France
+Centre Nationale d'Etudes des Telecommunications (org., France)
 
 @item CNI
 Certified Netware Instructor (Novell, Netware)
@@ -1133,16 +1142,16 @@ Connection Oriented (CL)
 Cache On A STick (Intel)
 
 @item COAST
-Computer Operations, Audit and Security Technology org.
+Computer Operations, Audit and Security Technology (org.)
 
 @item COBOL
 COmmon Business Orientated Language
 
 @item COBRA
-??? Org., Netherlands
+??? (org., Netherlands)
 
 @item COCA
-Cost Of Cracking Adjustment cryptography
+Cost Of Cracking Adjustment (cryptography)
 
 @item COCOT
 Customer Owned Coin Operated Telephone
@@ -1151,7 +1160,7 @@ Customer Owned Coin Operated Telephone
 Connection Oriented Data
 
 @item CODASYSL
-Conference On DAta Systems Languages conference
+Conference On DAta Systems Languages (conference)
 
 @item CODCF
 Central Office Data Connecting Facility
@@ -1172,7 +1181,7 @@ Central Office Equipment
 COE Engineering System (COE)
 
 @item COFDM
-??? digital audio
+??? (digital audio)
 
 @item COFF
 Common Object File Format (Unix)
@@ -1205,19 +1214,19 @@ Cache Only Memory Architecture (SMP)
 COMmon Algorithmic Language
 
 @item COMDEX
-COMputer Dealer's EXposition fair
+COMputer Dealer's EXposition (fair)
 
 @item COMPARTS
 COMputergestuetztes PARtner-TeilebestandsSystem (MBAG)
 
 @item COMTECH
-COMputer TECHnologies fair
+COMputer TECHnologies (fair)
 
 @item CONCERT
-Communications for North Carolina Education, Research and Technology network
+Communications for North Carolina Education, Research and Technology (network)
 
 @item CONCISE
-COSINE Network's Central Information Service for Europe COSINE, network
+COSINE Network's Central Information Service for Europe (COSINE, network)
 
 @item CONLAN
 ??? [hardware description language] (HDL)
@@ -1237,6 +1246,9 @@ Concurrent Object Orientated Programming (OOP)
 @item COP
 Character-Oriented Protocol
 
+@item COPA
+Child Online Protection Act (Internet, USA)
+
 @item CORAN
 Communication ORiented Application aNalysis
 
@@ -1244,7 +1256,7 @@ Communication ORiented Application aNalysis
 Common Object Request Broker Architecture (OMG)
 
 @item CORDIS
-COmmunity Research and Development Information Service Europe
+COmmunity Research and Development Information Service (Europe)
 
 @item COS
 Class of Service
@@ -1253,19 +1265,19 @@ Class of Service
 Clip On Socket (CPU)
 
 @item COS
-Corporation for Open Systems org., OSI, User group
+Corporation for Open Systems (org., OSI, user group)
 
 @item COSA
 COmputerunterstuetzte SAchbearbeitung
 
 @item COSA
-COmputing in der Sozialen Arbeit Org, Koeln, Germany
+COmputing in der Sozialen Arbeit (Org, Koeln, Germany)
 
 @item COSE
 Common Open Software Environment (HP, Sun, IBM, SCO, USL, Univel)
 
 @item COSINE
-Cooperation for OSI Networking in Europe org.
+Cooperation for OSI Networking in Europe (org.)
 
 @item COSMOS
 COmputer System for Mainframe OperationS
@@ -1358,7 +1370,7 @@ Central Point Management Services (Central Point)
 Calling Party Number
 
 @item CPN
-Compuserve Packet Network network
+Compuserve Packet Network (network)
 
 @item CPN
 Customer Premises Network
@@ -1376,7 +1388,7 @@ Characters Per Second
 Configurable PostScript Interpreter
 
 @item CPSR
-Computer Professionals for Social Responsibility org., USA
+Computer Professionals for Social Responsibility (org., USA)
 
 @item CPU
 Central Processing Unit
@@ -1403,7 +1415,7 @@ Cable Repair Administrative System
 Cyclic Redundancy Check
 
 @item CRCG
-[fraunhofer] Center for Research in Computer Graphics org., USA
+[fraunhofer] Center for Research in Computer Graphics (org., USA)
 
 @item CRCG
 Common Routing Connection Group
@@ -1412,7 +1424,7 @@ Common Routing Connection Group
 Color Rendering Dictionary (PS)
 
 @item CREN
-Corporation for Research and Educational Networking network
+Corporation for Research and Educational Networking (network)
 
 @item CRET
 Color - Resolution Enhancement Technology (HP), "C-REt"
@@ -1424,10 +1436,10 @@ Connection Related Function Virtual Channel (UPC, UNI), "CRF(VC)"
 Connection Related Function Virtual Path (UPC, UNI), "CRF(VP)"
 
 @item CRI
-Cray Research, Inc. manufacturer
+Cray Research, Inc. (manufacturer)
 
 @item CRIN
-Centre de Recherche en Informatique de Nancy Org., France
+Centre de Recherche en Informatique de Nancy (org., France)
 
 @item CRISC
 Complex-Reduced Instruction Set Computer
@@ -1457,7 +1469,7 @@ Cell Relay Service (UNI, ATM)
 Cathode Ray Tube
 
 @item CRT
-Computer Technology Research [corporation] provider
+Computer Technology Research [corporation] (provider)
 
 @item CRTC
 Cathode Ray Tube Controller (EGA, VGA, MCGA)
@@ -1469,10 +1481,10 @@ Carrier Selection
 Chip Select (IC)
 
 @item CS
-Client/Server, "C/S"
+Client/Server, "C/S" 
 
 @item CS
-Code Segment [register] CPU, Intel, assembler
+Code Segment [register] (CPU, Intel, assembler)
 
 @item CS
 Computer Science
@@ -1502,13 +1514,13 @@ Configuration Status Accounting
 Common Speller Application Program Interface (API)
 
 @item CSC
-Computer Sciences Corporation provider
+Computer Sciences Corporation (provider)
 
 @item CSCC
-Concurrent SuperComputing Consortium org.
+Concurrent SuperComputing Consortium (org.)
 
 @item CSCSI
-Canadian Society for the Computational Studies of Intelligence Org., Canada, AI
+Canadian Society for the Computational Studies of Intelligence (org., Canada, AI)
 
 @item CSCW
 Computer Supported Cooperative Work
@@ -1519,6 +1531,9 @@ Control flow Specification Diagram (CASE)
 @item CSD
 Corrective Service Diskettes (IBM)
 
+@item CSD
+Customer Specific Dictionaries
+
 @item CSDC
 Circuit Switched Digital Capability
 
@@ -1529,10 +1544,10 @@ Code Segment Descriptor Cache [register] (CS, Intel, CPU)
 Client-Server Environment
 
 @item CSEIA
-[conference on] Computer Support for Environmental Impact Assessment IFIP, conference
+[conference on] Computer Support for Environmental Impact Assessment (IFIP, conference)
 
 @item CSELT
-Centro Studi E Laboratori Telecomunicazioni [s.p.a.] Org., Italy
+Centro Studi E Laboratori Telecomunicazioni [s.p.a.] (org., Italy)
 
 @item CSES
 C-bit Severely Errored Seconds (DS3/E3)
@@ -1556,16 +1571,16 @@ Convergence Sublayer Indication (ATM)
 Caller Station IDentification (Fax)
 
 @item CSIDS
-Central command/Southern command Integrated Data System mil., USA
+Central command/Southern command Integrated Data System (mil., USA)
 
 @item CSII
-Center for Systems Interoperability and Integration org., ???
+Center for Systems Interoperability and Integration (org., ???)
 
 @item CSIRO
-Commonwealth Scientific and Industrial Research Organization org., UK
+Commonwealth Scientific and Industrial Research Organization (org., UK)
 
 @item CSIS
-Central Schengen Information Systen SIS, Europe, Strasbourg
+Central Schengen Information Systen (SIS, Europe, Strasbourg)
 
 @item CSL
 Computer SoLutions [software gmbh] (Haendler)
@@ -1577,10 +1592,10 @@ Compressed [headers] Serial Line Internet Protocol (SLIP, IP)
 Carrier Sense Multiple Access
 
 @item CSMACA
-Carrier Sense Multiple Access with Collision Avoidance, "CSMA/CA"
+Carrier Sense Multiple Access with Collision Avoidance, "CSMA/CA" 
 
 @item CSMACD
-Carrier Sense Multiple Access with Collision Detection IEEE 802.3, ethernet, "CSMA/CD"
+Carrier Sense Multiple Access with Collision Detection (IEEE 802.3, ethernet), "CSMA/CD"
 
 @item CSMS
 C Specific Media Support (NEST, MLID, Novell)
@@ -1592,10 +1607,10 @@ Circuit Switching MUltipleXer (FDDI), "CS-MUX"
 Card Select Number (PNP)
 
 @item CSNET
-Computer + Science NETwork USA, network, BITNET
+Computer + Science NETwork (USA, network, BITNET)
 
 @item CSP
-Centro Supercacolo Piemonte Org., Italy, HPC
+Centro Supercacolo Piemonte (org., Italy, HPC)
 
 @item CSP
 Chip Scale Package (IC)
@@ -1613,7 +1628,7 @@ Circuit Switched Public Data Network (IN)
 Convergence Sublayer Protocol Data Unit (ATM, PDU), "CS PDU"
 
 @item CSPP
-Computer Systems Policy Project [group] Org., USA. manufacturer
+Computer Systems Policy Project [group] (org., USA. manufacturer)
 
 @item CSR
 Cell misSequenced Ratio (ATM)
@@ -1621,8 +1636,11 @@ Cell misSequenced Ratio (ATM)
 @item CSR
 Cell Switch Router (Toshiba)
 
+@item CSRAM
+Clock Synchronous Random Access Memory (RAM, IC)
+
 @item CSS
-Cascading Style Sheets (HTML, WWW)
+Cascading Style Sheets (HTML, WWW,  JavaScript)
 
 @item CSS
 Computer Sub System
@@ -1643,13 +1661,16 @@ Central Standard Time [-0600] (TZ, CDT, USA)
 Computer Supported Telecommunications Applications (ECMA, CTI)
 
 @item CSTB
-Computer Science and Technology Board org., NRC
+Computer Science and Technology Board (org., NRC)
 
 @item CSTC
-Computer Security Technology Center org., CIAC
+Computer Security Technology Center (org., CIAC)
 
 @item CSTO
-Computing Systems Technology Office org., ARPA
+Computing Systems Technology Office (org., ARPA)
+
+@item CSTR
+Centre for Speech Technology Research
 
 @item CSTS
 Computer Supported Telecommunications Standard
@@ -1658,16 +1679,16 @@ Computer Supported Telecommunications Standard
 Channel Service Unit (ATM)
 
 @item CSUNET
-California State University NETwork network, USA
+California State University NETwork (network, USA)
 
 @item CSV
 Comma Separated Values
 
 @item CT
-[magazin fuer] Computer Technik, "c't"
+[magazin fuer] Computer Technik, "c't" 
 
 @item CT
-Chips & Technologies manufacturer, "C&T"
+Chips & Technologies (manufacturer), "C&T"
 
 @item CTAN
 Comprehensive Tex Archive Network (TeX, FTP)
@@ -1697,16 +1718,16 @@ Command TERMinal (DEC)
 Computer Telephony Integration
 
 @item CTR
-[columbia university] Center for Telecommunications Research org., USA
+[columbia university] Center for Telecommunications Research (org., USA)
 
 @item CTR
-Common Technical Regulations Europe
+Common Technical Regulations (Europe)
 
 @item CTRON
 Central TRON (TRON)
 
 @item CTS
-Cipher Text Stealing [mode] cryptography
+Cipher Text Stealing [mode] (cryptography)
 
 @item CTS
 Clear To Send (MODEM, RS-232)
@@ -1718,7 +1739,7 @@ Conformance Testing Service (OSTC)
 C Topology Specific Module (NEST, MLID, Novell)
 
 @item CTSS
-Compatible / Cray Time Sharing System Unix, predecessor, OS
+Compatible / Cray Time Sharing System (Unix, predecessor, OS)
 
 @item CTT
 Cartridge Tape Transport
@@ -1739,7 +1760,7 @@ Console teleTYpe
 Call Up (Unix)
 
 @item CU
-[L]       [see you [Later]] slang, Usenet, IRC
+[L]       [see you [Later]] (slang, Usenet, IRC)
 
 @item CUA
 Common User Application
@@ -1766,7 +1787,7 @@ ComputerUnterstuetzte Unterweisung
 Compressed Volume File (DOS)
 
 @item CVIA
-Computer Virus Industry Association org., USA
+Computer Virus Industry Association (org., USA)
 
 @item CVS
 Computer Vision Syndrome
@@ -1775,7 +1796,7 @@ Computer Vision Syndrome
 Codex Vector Sum Excited Linear Prediction [algorithm] (Motorola, VOFR)
 
 @item CWI
-Centrum voor Wiskunde en Informatica Org., Netherlands
+Centrum voor Wiskunde en Informatica (org., Netherlands)
 
 @item CWIS
 Campus Wide Information System
@@ -1790,7 +1811,8 @@ Character Width Table
 Common X-windows Interface (Unix)
 
 @item CYMK
-Cyan, Yellow, Magenta, blacK color system
+Cyan, Yellow, Magenta, blacK (color system)
 
 @end table
 
+
