@@ -35,13 +35,13 @@ File Access Data Unit (FTAM)
 FernmeldeAnlagenGesetz
 
 @item FAIS
-Finnish Artificial Intelligence Society Org., Finland, AI
+Finnish Artificial Intelligence Society (org., Finland, AI)
 
 @item FAL
 File Access Listener (DEC, DNA)
 
 @item FAME
-FORMEX Applied to Multilingualism in Europe SGML, Europe
+FORMEX Applied to Multilingualism in Europe (SGML, Europe)
 
 @item FAMOS
 Floating gate Avalanche injection Metal Oxide Semiconductor (IC)
@@ -53,7 +53,7 @@ Flow Attribute Notification Protocol (Toshiba, RFC 2129)
 Family Application Programmer Interface (DOS, VDM, API)
 
 @item FAQ
-Frequently Asked Questions slang, Usenet
+Frequently Asked Questions (slang, Usenet)
 
 @item FAR
 Fixed Alternative Routing (SNI)
@@ -62,7 +62,7 @@ Fixed Alternative Routing (SNI)
 Flow Admission Request [message] (LFAP)
 
 @item FARNET
-Federation of American Research NETworks network
+Federation of American Research NETworks (network)
 
 @item FAS
 Flow Admission Service
@@ -74,7 +74,7 @@ Fast Analysis of Shared Multidimensional Information (OLAP)
 First Application System Test
 
 @item FAST
-Forschungsinstitut fuer Angewandte Software-Technologie [e.v.] org.
+Forschungsinstitut fuer Angewandte Software-Technologie [e.v.] (org.)
 
 @item FAT
 File Allocation Table (DOS)
@@ -83,10 +83,10 @@ File Allocation Table (DOS)
 Flow Admission Update [message] (LFAP)
 
 @item FAU
-Friedrich-Alexander-Universitaet Org., Erlangen, Germany, Nuernberg
+Friedrich-Alexander-Universitaet (org., Erlangen, Germany, Nuernberg, Germany)
 
 @item FAW
-Forschungsinstitut fuer Anwendungsorientierte Wissensverarbeitung org., KI, Ulm
+Forschungsinstitut fuer Anwendungsorientierte Wissensverarbeitung (org., KI, Ulm)
 
 @item FB
 Fiber optic Backbone
@@ -119,7 +119,7 @@ Frame Control (FDDI, Token Ring)
 Flow Control Ack (DLSW)
 
 @item FCAL
-Fibre Channel - Arbitrated Loop, "FC-AL"
+Fibre Channel - Arbitrated Loop, "FC-AL" 
 
 @item FCAPS
 Fault, Configuration, Accounting, Performance, Security [management areas]
@@ -131,7 +131,7 @@ File Control Block (DOS)
 File Control BlockS (DOS)
 
 @item FCC
-Federal Communications Commission org., USA
+Federal Communications Commission (org., USA)
 
 @item FCC
 Forward Carbon Copy (DFUE)
@@ -140,7 +140,7 @@ Forward Carbon Copy (DFUE)
 Frequency Correction CHannel (GSM)
 
 @item FCCN
-Fundacao para a Computacao Cientifica Nacional org., Portugal
+Fundacao para a Computacao Cientifica Nacional (org., Portugal)
 
 @item FCFS
 First Come, First Served
@@ -194,16 +194,16 @@ Floppy Disk Drive
 Fiber Distributed Data Interface (ANSI, ISO 8314)
 
 @item FDDITPPMD
-FDDI Twisted Pair-Physical layer, Medium Dependent, "FDDI TP-PMD"
+FDDI Twisted Pair-Physical layer, Medium Dependent, "FDDI TP-PMD" 
 
 @item FDE
-Full Duplex Ethernet ethernet
+Full Duplex Ethernet (ethernet)
 
 @item FDES
 Full Duplex EtherSwitch (Kalpana)
 
 @item FDI
-[fachverband der ] Fuehrungskraefte der Druckindustrie und Informationsverarbeitung org.
+[fachverband der ] Fuehrungskraefte der Druckindustrie und Informationsverarbeitung (org.)
 
 @item FDL
 File Definition Language
@@ -230,10 +230,10 @@ Functional Entity (IN)
 Functional Entity Action (IN, UNI)
 
 @item FEAL
-Fast Data Encipherment Algorithm DES, cryptography
+Fast Data Encipherment Algorithm (DES, cryptography)
 
 @item FEAST
-Fast Data Enciphering Algorithm cryptography
+Fast Data Enciphering Algorithm (cryptography)
 
 @item FEBE
 Far End Block Error (SONET)
@@ -260,13 +260,13 @@ Free-net Erlangen/Nuernberg
 Front End Processor
 
 @item FER
-Forward Error Correction satellite
+Forward Error Correction (satellite)
 
 @item FERF
 Far End Receive Failure (UNI, ATM, SONET, OAM)
 
 @item FESI
-Federacion Espanola de Sociedades de Informatica org.
+Federacion Espanola de Sociedades de Informatica (org.)
 
 @item FET
 Field Effect Transistor
@@ -323,13 +323,13 @@ FreeHand Graphics Studio (Macromedia, DTP)
 Frequency Hopping Spread Spectrum (Wireless LAN)
 
 @item FIA
-Fiberoptic Industry Association org.
+Fiberoptic Industry Association (org.)
 
 @item FIBU
 FInanzBUchhaltung
 
 @item FIC
-First International Computer [inc.] manufacturer
+First International Computer [inc.] (manufacturer)
 
 @item FID
 File Identifier Descriptor (UDF, CD-R)
@@ -338,13 +338,13 @@ File Identifier Descriptor (UDF, CD-R)
 Fractal Interchange Format
 
 @item FIFF
-Forum Informatikerinnen Fuer den Frieden org.
+Forum Informatikerinnen Fuer den Frieden (org.)
 
 @item FIFO
 First In First Out (CPU)
 
 @item FIG
-Forth Interest Group org., Forth
+Forth Interest Group (org., Forth)
 
 @item FIGLET
 Frank, Ian and Glenn's LETters (ASCII, fonts)
@@ -353,7 +353,7 @@ Frank, Ian and Glenn's LETters (ASCII, fonts)
 First In Last Out
 
 @item FIMAS
-Financial Institution Message Authentication Standard banking, ANSI
+Financial Institution Message Authentication Standard (banking, ANSI)
 
 @item FIOC
 Frame Input/Output Controller
@@ -368,7 +368,7 @@ Factory Instrumentation Protocol
 Fluorescent Indicator Panel
 
 @item FIPA
-Foundation for Intelligent Physical Agents org., Agents
+Foundation for Intelligent Physical Agents (org., Agents)
 
 @item FIPS
 Federal Information Processing Standard (NIST, USA)
@@ -383,10 +383,10 @@ Federal Information Resources Management Regulations (USA)
 Federal Internet Requirements Panel (Internet, USA)
 
 @item FIRST
-ForschungsInstitut fuer Rechnerarchitektur und SoftwareTechnik Org., GMD, Berlin, Germany
+ForschungsInstitut fuer Rechnerarchitektur und SoftwareTechnik (org., GMD, Berlin, Germany)
 
 @item FIRST
-Forum of Incident Response and SecuriTy org., NIST
+Forum of Incident Response and SecuriTy (org., NIST)
 
 @item FIS
 FachInformationsSystem
@@ -431,7 +431,7 @@ Faithful Library about Internet Message (EMACS, GNU)
 FLoating-point Operations Per Second (CPU)
 
 @item FLP
-Fast Link Pulse ethernet, LAN, NLP
+Fast Link Pulse (ethernet, LAN, NLP)
 
 @item FLS
 ???
@@ -446,19 +446,19 @@ Flash Memory Manager (Intel)
 FernMeldeSystem
 
 @item FNC
-Federal Networking Council org., USA
+Federal Networking Council (org., USA)
 
 @item FO
 Fiber Optic
 
 @item FOA
-Fiber Optic Association org.
+Fiber Optic Association (org.)
 
 @item FOC
 Fiber Optic Cable / Communications
 
 @item FOCS
-[symposium on] Foundations Of Computer Science conference
+[symposium on] Foundations Of Computer Science (conference)
 
 @item FOD
 Flexible Optical Disk (OD)
@@ -467,22 +467,25 @@ Flexible Optical Disk (OD)
 Formal specification of ODA document structures (ODA, ISO)
 
 @item FODO
-[international conference on] Foundations Of Data Organization and algorithms conference, INRIA
+[international conference on] Foundations Of Data Organization and algorithms (conference, INRIA)
 
 @item FOEBUD
-[verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] org., "FoeBud"
+[verein zur] Foerderung des OEffentlichen Bewegten und Unbewegten Datenverkehrs [e.v.] (org.), "FoeBud"
 
 @item FOIRL
 Fiber Optic InterRepeater Link (OWG)
 
 @item FOKUS
-Forschungszentrum fuer Offene KommUnikationsSysteme Org., GMD, Berlin, Germany
+Forschungszentrum fuer Offene KommUnikationsSysteme (org., GMD, Berlin, Germany)
 
 @item FOLDOC
 Free OnLine Dictionary Of Computing (WWW, UK)
 
+@item FOLED
+Flexible Organic Light Emitting Display (OLED)
+
 @item FOMAU
-Fiber Optic MAU ethernet
+Fiber Optic MAU (ethernet)
 
 @item FON
 Fiber Optics Network
@@ -494,7 +497,7 @@ FTP Operation Over Big Address Records (RFC 1639, FTP)
 Forum for Object Oriented Technology (CERN, OOP)
 
 @item FORMEX
-FORMalised EXchange of electronic publications SGML, Europe
+FORMalised EXchange of electronic publications (SGML, Europe)
 
 @item FORML
 Formal Object Role Modelling Language
@@ -503,10 +506,10 @@ Formal Object Role Modelling Language
 FORmula TRANslation
 
 @item FORTWIHR
-FORschungsverbund fuer Technisch-WIssenschaftliches HochleistungsRechnen Org., Bavaria
+FORschungsverbund fuer Technisch-WIssenschaftliches HochleistungsRechnen (org., Bavaria)
 
 @item FORWISS
-bayerisches FORschungszentrum fuer WISsensbasierte Systeme org., KI
+bayerisches FORschungszentrum fuer WISsensbasierte Systeme (org., KI)
 
 @item FOSI
 Format Output Specification Instance (SGML, CALS)
@@ -611,7 +614,7 @@ Functional Requirements Description
 Floatingpoint Register File (DEC, Alpha, CPU)
 
 @item FRICC
-Federal Research Internet Coordinating Committee org.
+Federal Research Internet Coordinating Committee (org.)
 
 @item FRL
 Frame Representation Language (AI)
@@ -638,16 +641,19 @@ File System (LVM)
 Frame Status (FDDI, Token Ring)
 
 @item FSAG
-Free Software Association of Germany org.
+Free Software Association of Germany (org.)
 
 @item FSB
 For Small Business (Novell)
 
+@item FSB
+Front Side Bus
+
 @item FSCK
 File System Consistency checK (Unix)
 
 @item FSF
-Free Software Foundation org., GNU
+Free Software Foundation (org., GNU)
 
 @item FSK
 Frequency Shift Keying (DFUE)
@@ -674,7 +680,7 @@ Film SuperTwisted Nematic (LCD)
 Foiled Shielded Twisted Pair [cable] (STP, TP), "F/STP"
 
 @item FSU
-Free Software Union org.
+Free Software Union (org.)
 
 @item FT1
 Fractional T1 (ISDN, T1, DS-0, DS-1)
@@ -686,7 +692,7 @@ Floptical Technology Association (3M u.a.)
 File Transfer, Access  and Management (GOSIP, ISO 8571/8572)
 
 @item FTC
-Federal Trade Commission org., USA
+Federal Trade Commission (org., USA)
 
 @item FTE
 [DCOM] For The Enterprise (DCOM, SAG)
@@ -719,25 +725,28 @@ Fidonet Technical Standard
 Federal Telecommunications Services - 2000 (USA), "FTS-2000"
 
 @item FTSC
-Federal Telecommunications Standards Committee org., USA
+Federal Telecommunications Standards Committee (org., USA)
 
 @item FTSC
-Fidonet Technical Standard Conference conference
+Fidonet Technical Standard Conference (conference)
 
 @item FTZ
-FernmeldeTechnische Zentralamt / Zulassung Telekom, ZZF, predecessor
+FernmeldeTechnische Zentralamt / Zulassung (Telekom, ZZF, predecessor)
 
 @item FUA
 Flow Update Acknowledge [message] (LFAP)
 
 @item FUB
-Freie Universitaet Berlin org.
+Freie Universitaet Berlin (org.)
 
 @item FUBAB
-Fouled / Fucked Up Beyond All Belief slang, Usenet, IRC
+Fouled / Fucked Up Beyond All Belief (slang, Usenet, IRC)
 
 @item FUBAR
-Fouled / Fucked Up Beyond All Recognition / Repair slang, Usenet, IRC
+Fouled / Fucked Up Beyond All Recognition / Repair (slang, Usenet, IRC)
+
+@item FUD
+Fear, Uncertainty, & Doubt (slang, IBM)
 
 @item FUN
 Flow Update Notification [message] (LFAP)
@@ -745,10 +754,11 @@ Flow Update Notification [message] (LFAP)
 @item FUNI
 Frame User Network Interface
 
-FUEV          Fernmeldeanlagen-UEberwachungsVerordnung
+@item FUEV
+Fernmeldeanlagen-UEberwachungsVerordnung
 
 @item FWIW
-For What It's Worth slang, Usenet, IRC
+For What It's Worth (slang, Usenet, IRC)
 
 @item FWT
 Fast Wavelet Transformation
@@ -757,13 +767,14 @@ Fast Wavelet Transformation
 FiXed point Unit (POWER, CPU)
 
 @item FYI
-For Your Information slang, Usenet, IRC
+For Your Information (slang, Usenet, IRC)
 
 @item FZA
 ??? [compression]
 
 @item FZI
-ForschungsZentrum Informatik Org., Uni Karlsruhe, Germany
+ForschungsZentrum Informatik (org., Uni Karlsruhe, Germany)
 
 @end table
 
+
