@@ -11,7 +11,7 @@ Mandatory Access Control (MLS)
 Media Access Control (ISO, OSI)
 
 @item MAC
-Message Authentication Code SSL, SRT, cryptography
+Message Authentication Code (SSL, SRT, cryptography)
 
 @item MACH
 Multilayer ACtuator Head
@@ -35,7 +35,7 @@ Memory Address Driver strength (BIOS)
 Message Address Directory
 
 @item MAD
-Militaerischer AbschirmDienst mil., Org.
+Militaerischer AbschirmDienst (mil., org.)
 
 @item MADE
 Multimedia Application Development Environment (CWI)
@@ -49,6 +49,9 @@ MAchine INdependent SAIL (SAIL)
 @item MAJOUR
 Modular Application for JOURnals (EWS, SGML)
 
+@item MAME
+Multiple Arcade Machine Emulator, "M.A.M.E."
+
 @item MAN
 Metropolitan Area Network
 
@@ -71,7 +74,7 @@ Mobile Application Part - Application Service Elements (MAP, MSC, GSM), "MAP-ASE
 Messaging Application Program Interface (MS, WOSA, API)
 
 @item MAPTOP
-Manufacturing Automation Protocol/Technical Office Protocol, "MAP/TOP"
+Manufacturing Automation Protocol/Technical Office Protocol, "MAP/TOP" 
 
 @item MAR
 Microprogram Address Register
@@ -86,7 +89,7 @@ Mittelstands-Anwendungs-System 90 (IBM)
 Message Administration Service Element
 
 @item MASM
-Microsoft ASseMbler MS, assembler
+Microsoft ASseMbler (MS, assembler)
 
 @item MAU
 Medium Access Unit
@@ -98,7 +101,7 @@ Medium Attachment Unit (IEEE 802.3, Transceiver)
 Multistation Access Unit (Token Ring, Hub)
 
 @item MAUS
-Muensters Apple User Service BBS, network, "M.A.U.S."
+Muensters Apple User Service (BBS, network), "M.A.U.S."
 
 @item MAW
 Microsoft At Work
@@ -158,13 +161,13 @@ Manchester Computing Centre (Linux)
 Mitteldeutsches Communication Center (Leipzig)
 
 @item MCD
-Mini Client Driver MS, Windows NT
+Mini Client Driver (MS, Windows NT)
 
 @item MCD
 Multimedia Cartridge Drive (Nomai)
 
 @item MCEB
-Military Communications-Electronics Board Org., mil., USA
+Military Communications-Electronics Board (org., mil., USA)
 
 @item MCF
 Meta Content Framework / Format (Apple, WWW)
@@ -182,7 +185,7 @@ Media Control Interface
 Microwave Communications Incorporated
 
 @item MCL
-Media Communication Lab org., Uni Boston, USA
+Media Communication Lab (org., Uni Boston, USA)
 
 @item MCM
 MultiChip Module (CPU)
@@ -190,8 +193,11 @@ MultiChip Module (CPU)
 @item MCN
 Metropolitan Campus Network
 
+@item MCNE
+Master Certified Netware Engineer (Novell, Netware)
+
 @item MCNS
-??? [cable modem standard] org.
+??? [cable modem standard] (org.)
 
 @item MCP
 Master Control Program
@@ -200,13 +206,13 @@ Master Control Program
 Multiport / Multiprotocol Communication Processor
 
 @item MCPAS
-Master Control Program/Advanced System, "MCP/AS"
+Master Control Program/Advanced System, "MCP/AS" 
 
 @item MCPC
 Multi Channel Per Carrier
 
 @item MCPS
-Microsoft Certified Product Specialist (MS)
+Microsoft Certified Product Specialist (MS, ATEC)
 
 @item MCR
 Minimum Cell Rate (UNI, ATM, PCR, ABR)
@@ -227,10 +233,10 @@ Multichannel Communications System (Mac)
 Multivender Customer Services (DEC)
 
 @item MCSD
-Microsoft Certified Solution Developer (MS)
+Microsoft Certified Solution Developer (MS, ATEC)
 
 @item MCSE
-Microsoft Certified System Engineer (MS)
+Microsoft Certified System Engineer (MS, ATEC)
 
 @item MCSMP
 Message Conversion System Message Processor (MCS)
@@ -238,6 +244,9 @@ Message Conversion System Message Processor (MCS)
 @item MCSS
 Mitac Computer Security System (Mitac)
 
+@item MCT
+Microsoft Certified Trainer (MS, ATEC)
+
 @item MCTD
 Mean Cell Transfer Delay (UNI, ATM)
 
@@ -290,10 +299,10 @@ Message conversion system directory Component (MCS)
 ??? DatenErfassung
 
 @item MDI
-Medium Dependent Interface ethernet
+Medium Dependent Interface (ethernet)
 
 @item MDI
-Mobile Data Initiative org., GSM
+Mobile Data Initiative (org., GSM)
 
 @item MDI
 Multiple Document Interface (MS, Windows)
@@ -332,7 +341,7 @@ Mountain Daylight Time [-0600] (TZ, MST, USA)
 Mapping Entity
 
 @item MEG
-Mega Evil Grin slang, Usenet, IRC
+Mega Evil Grin (slang, Usenet, IRC)
 
 @item MEGA
 MessdatenErfassung und Graphische Auswertung
@@ -341,7 +350,7 @@ MessdatenErfassung und Graphische Auswertung
 Maya Embedded Language
 
 @item MEMS
-Micro-ElectroMechanical Systems
+Micro-ElectroMechanical System
 
 @item MERS
 Most Economic Route Selection
@@ -458,7 +467,7 @@ Multimedia and Hypermedia information coding Expert Group (JTC1, ISO)
 [columbia] Mobile Host Protocol
 
 @item MHPCC
-Maui High Performance Computing Center org., USA
+Maui High Performance Computing Center (org., USA)
 
 @item MHS
 Message Handling System (GOSIP, X.400, Novell, SPX, IPX)
@@ -515,13 +524,13 @@ Media Independent Interface
 Matrox Imaging Library
 
 @item MILNET
-MILitary NETwork USA, mil., Netzwerk
+MILitary NETwork (USA, mil., network)
 
 @item MILSTAR
-Military Strategic TActical Relay mil., USA
+Military Strategic TActical Relay (mil., USA)
 
 @item MILSTD
-Military STandarD mil., USA, "MIL-STD"
+Military STandarD (mil., USA), "MIL-STD"
 
 @item MIMD
 Multiple Instruction [stream], Multiple Data [stream]
@@ -551,7 +560,7 @@ Multimedia Information Network eXchange
 Memory Input/Output (Motorola)
 
 @item MIO
-Modular Input/Output (HP)
+Modular Input/Output [architecture] (HP)
 
 @item MIPS
 Microprocessor without Interlocked Piped Stages
@@ -572,7 +581,7 @@ Management Information System
 Mecklenburg Internet Service System (ISP)
 
 @item MISSI
-Multilevel Information System Security Initiative org.
+Multilevel Information System Security Initiative (org.)
 
 @item MISX
 Metered Services Information eXchange (Internet)
@@ -581,13 +590,13 @@ Metered Services Information eXchange (Internet)
 Management Information Tree
 
 @item MIT
-Massachusetts Institute of Technology org., USA
+Massachusetts Institute of Technology (org., USA)
 
 @item MJ
 Modular Jack
 
 @item MKS
-Mortice Kern Systems manufacturer
+Mortice Kern Systems (manufacturer)
 
 @item ML
 Mail List
@@ -641,19 +650,19 @@ MuLTilevel-3 [encoding] (Schneider & Koch, FDDI), "MLT-3"
 Media Manager (Novell, Netware, SMS)
 
 @item MM
-Military Message mil.
+Military Message (mil.)
 
 @item MM
 Mobile Management (RR, CM, GSM)
 
 @item MMA
-Microcomputer Managers Association org., USA
+Microcomputer Managers Association (org., USA)
 
 @item MMA
-MIDI Manufacturer Association org., IMA
+MIDI Manufacturer Association (org., IMA)
 
 @item MMC
-Microsoft Management Console MS, Windows NT
+Microsoft Management Console (MS, Windows NT)
 
 @item MMC
 MIDI Machine Control
@@ -668,7 +677,7 @@ MultiMedia Compact Disk (Sony, Philips, CD)
 MultiMedia Compact Disk - Erasable (Sony, Philips, CD), "MMCD-E"
 
 @item MMCF
-MultiMedia Communications Forum org.
+MultiMedia Communications Forum (org.)
 
 @item MMDO
 Magnetic Modulation Direct Overwrite
@@ -689,7 +698,7 @@ Multimode Fiberoptic cable
 Manufacturing Message Format Standard (MAP)
 
 @item MMHS
-Military Message Handling System mil., MHS
+Military Message Handling System (mil., MHS)
 
 @item MML
 Maker Markup Language (FrameMaker)
@@ -760,6 +769,12 @@ Measure of Effectiveness
 @item MOLAP
 Multidimensional OnLine Analytical Processing (OLAP)
 
+@item MOLED
+Molecule Organic Light Emitting Display (OLED)
+
+@item MOLI
+Microsoft OnLine Institute (MS)
+
 @item MOLP
 Microsoft Open Licence Pack (MS)
 
@@ -770,7 +785,7 @@ Message Orientated Middleware (IBM)
 MOdelling NAturaL Images for Synthesis and Animation, "MONA LISA"
 
 @item MONET
-high data rate MObile interNET network
+high data rate MObile interNET (network)
 
 @item MOO
 MUD Object Orientated (Internet, OOP, MUD)
@@ -824,7 +839,7 @@ Microsoft Overlay Virtual Environment (MS)
 [projekt] MObile VIsualisierung (DFG)
 
 @item MOWORM
-Magneto-Optical Write Once Read Many, "MO-WORM"
+Magneto-Optical Write Once Read Many, "MO-WORM" 
 
 @item MP
 [PPP] Multilink Protocol (MPPP, RFC 1990)
@@ -854,7 +869,7 @@ MultiPlatform DiskArray
 Message Protocol Data Unit (PDU)
 
 @item MPEG
-Motion Picture Expert Group org., ISO 11172-1, JTC1
+Motion Picture Expert Group (org., ISO 11172-1, JTC1)
 
 @item MPEXL
 ??? (HP), "MPE/XL"
@@ -866,7 +881,7 @@ Message Passing Interface (SMP)
 Multiprocessor Interconnect Bus
 
 @item MPIF
-Message Passing Interface Forum manufacturer
+Message Passing Interface Forum (manufacturer)
 
 @item MPM
 Metra Potential Method
@@ -875,7 +890,7 @@ Metra Potential Method
 MultiMedia Presentation Manager/2 (OS/2, IBM), "MPM/2"
 
 @item MPML
-Main Profile @@ Main Level (MPEG), "MP@@ML"
+Main Profile @@@ Main Level (MPEG), "MP@@ML"
 
 @item MPOA
 Multi-Protocol Over ATM (ATM)
@@ -902,7 +917,7 @@ Multi Purpose Peripheral Device
 Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend)
 
 @item MPR
-[National Board for Metrology and Testing] org., Schweden
+[National Board for Metrology and Testing] (org., Sweden)
 
 @item MPS
 Megabytes Per Second
@@ -920,7 +935,7 @@ MultiProzessor Spezifikation (SMP)
 Mathematical Programming System eXtended (IBM)
 
 @item MPT
-Ministery of Post and Telecommunications org., Japan
+Ministery of Post and Telecommunications (org., Japan)
 
 @item MPT
 MultiPort Transceiver
@@ -938,7 +953,7 @@ Multi Protocol Transport Networking (IBM)
 Multi Protocol Transport Services (IBM, MPTN)
 
 @item MPTS2
-Multi Protocol Transport Services / 2 (IBM, OS/2), "MPTN/2"
+Multi Protocol Transport Services / 2 (IBM, OS/2), "MPTN/2" 
 
 @item MPU
 MicroProcessor Unit
@@ -986,7 +1001,7 @@ Multi-Rate Circuit Switching
 Macintosh / MacOS Runtime for Java (Java, Apple)
 
 @item MRNET
-Minnesota Regional NETwork network, USA
+Minnesota Regional NETwork (network, USA)
 
 @item MRO
 Mandatory Router Option [flag] (CATNIP)
@@ -1025,7 +1040,7 @@ Message Store
 Meta Signaling (ATM, ???)
 
 @item MS
-MicroSoft manufacturer
+MicroSoft (manufacturer, MS)
 
 @item MS
 Mobile Station (GSM)
@@ -1088,7 +1103,7 @@ Management Service Focal Point (IBM)
 Medium Scale Integration
 
 @item MSI
-Micro-Star International manufacturer, Taiwan
+Micro-Star International (manufacturer, Taiwan)
 
 @item MSIE
 MicroSoft Internet Explorer (MS, WWW)
@@ -1175,7 +1190,7 @@ Machine Status Word
 Machine [assisted] Translation
 
 @item MT
-Mannesmann Tally [gmbh] manufacturer
+Mannesmann Tally [gmbh] (manufacturer)
 
 @item MT
 Message Transfer / Type
@@ -1211,7 +1226,7 @@ Mean Time Data Availability
 MuTating Engine (Viren), "MtE"
 
 @item MTEC
-Motorola Training and Education Center org., Chicago
+Motorola Training and Education Center (org., Chicago)
 
 @item MTF
 Message Text Formats
@@ -1223,7 +1238,7 @@ Microsoft Tape Format (MS)
 Modulation Transfer Function
 
 @item MTI
-MIPS Technologies Inc. manufacturer, SGI
+MIPS Technologies Inc. (manufacturer, SGI)
 
 @item MTP
 Message Transfer Part (ISDN, GSM)
@@ -1265,7 +1280,7 @@ Multi-User Chat Kingdom (MUD)
 Multi-User Dungeon (MUD)
 
 @item MUGD
-MUMPS User Group Deutschland MUMPS, user group, "MUG-D"
+MUMPS User Group Deutschland (MUMPS, user group), "MUG-D"
 
 @item MUI
 Management User Interface (OMF, UI)
@@ -1289,21 +1304,22 @@ MULtimedia Office Server (OA, BIS, ESPRIT)
 Massachusetts general hospital Multi-Programming System
 
 @item MUPAD
-Multi Processing Algebra Data [tool] Uni Paderborn, Germany, CAS, "MuPAD"
+Multi Processing Algebra Data [tool] (Uni Paderborn, Germany, CAS), "MuPAD"
 
 @item MUSH
 Multi-User Shared Hallucination (MUD)
 
 @item MUSICAM
-Masking-pattern adapted Universal Subband Integrated Coding And Multiplexing MPEG, digital audio
+Masking-pattern adapted Universal Subband Integrated Coding And Multiplexing (MPEG, digital audio)
 
 @item MUT
 Master Upper Tester (ISO 9646-3, TTCN)
 
 @item MUTOS
-MultiUser-/multitasking Operating System GDR, OS
+MultiUser-/multitasking Operating System (GDR, OS)
 
-MUEW          eW MonopolUEbertragungsWeg, "MueW"
+@item MUEW
+eW MonopolUEbertragungsWeg, "MueW"
 
 @item MUX
 MUltipleXer
@@ -1318,7 +1334,7 @@ Model View Controller (Smalltalk, GUI)
 Motion Video Instructions (DEC, CPU, Alpha)
 
 @item MVIF
-Multi-Vendor Interacting Forum org., IN
+Multi-Vendor Interacting Forum (org., IN)
 
 @item MVP
 Most Valuable Professional [bonus program] (MS)
@@ -1339,13 +1355,13 @@ Multiple Virtual Storage/Extended System Architecture (IBM), "MVS/ESA"
 Multiple Virtual Storage/Extended System Architecture System Product (IBM), "MVS/ESA SP"
 
 @item MVSSP
-Multiple Virtual Storage/System Product, "MVS/SP"
+Multiple Virtual Storage/System Product, "MVS/SP" 
 
 @item MVSTSO
 Multiple Virtual Storage/Time Sharing Option (IBM), "MVS/TSO"
 
 @item MVSXA
-Multiple Virtual Storage/eXtended Architecture, "MVS/XA"
+Multiple Virtual Storage/eXtended Architecture, "MVS/XA" 
 
 @item MWS
 Management WorkStation
@@ -1367,3 +1383,4 @@ Mark Zbikowski (MS-DOS, MCB)
 
 @end table
 
+
